"""`tket2-eccs` is a Python package containing compiler rewrite sets used for `tket2`'s optimisation passes.

This package is intended to be used as an internal dependency for `tket2`.
"""

# This is updated by our release-please workflow, triggered by this
# annotation: x-release-please-version
__version__ = "0.1.0"

from importlib import resources
from pathlib import Path


def nam_6_3() -> Path:
    """Get the path to the included `nam_6_3.rwr` rewriter.

    This is a rewrite set obtained from the equivalence classes of circuits with
    up to 3 qubits and 6 gates on the Nam gateset, as
    generated by TASO.

    See https://dl.acm.org/doi/10.1145/3341301.3359630
    """
    with resources.as_file(
        resources.files("tket2_eccs").joinpath("data/nam_6_3.rwr")
    ) as r:
        rewriter = Path(r)
    return rewriter
